@@ -203,7 +203,11 @@ void adapter_loop() {
 
    // loop
 
-   while (true) adapter_step();
+   while (true) {
+     adapter_step();
+     sleep( 0 ); // Otherwise, sometimes the program will crash while spending
+                 // a long time solving a position
+   }
 }
 
 // adapter_step()
@@ -696,7 +700,7 @@ static void xboard_step() {
          my_argv[0] = (char *)malloc( 2 );
          my_argv[1] = (char *)malloc( 10 );
          my_argv[2] = (char *)malloc( 5 );
-         my_argv[3] = (char *)malloc( sizeof(token) + 1 );
+         my_argv[3] = (char *)malloc( strlen(token) + 1 );
          strcpy( my_argv[0], "g" );
          strcpy( my_argv[1], "make-book" );
          strcpy( my_argv[2], "-pgn" );
@@ -706,6 +710,7 @@ static void xboard_step() {
       } else if ( strcmp( token, "on" ) == 0 ) {
 
          option_set("Book","true");
+         book_open(option_get_string("BookFile"));
 
       } else if ( strcmp( token, "off" ) == 0 ) {
 
